HKStatisticsCollectionQuery

Struct HKStatisticsCollectionQuery 

pub struct HKStatisticsCollectionQuery { /* private fields */ }
Available on crate features HKQuery and HKStatisticsCollectionQuery only.
Implementations

Source

impl HKStatisticsCollectionQuery

pub unsafe fn anchorDate(&self) -> Retained<NSDate>

pub unsafe fn options(&self) -> HKStatisticsOptions

Available on crate feature HKStatistics only.
pub unsafe fn intervalComponents(&self) -> Retained<NSDateComponents>

pub unsafe fn initialResultsHandler( &self, ) -> *mut DynBlock<dyn Fn(NonNull<HKStatisticsCollectionQuery>, *mut HKStatisticsCollection, *mut NSError)>

Available on crate feature block2 only.

This property is not atomic.

Safety
  • The returned block must be sendable.
  • This might not be thread-safe.
pub unsafe fn setInitialResultsHandler( &self, initial_results_handler: Option<&DynBlock<dyn Fn(NonNull<HKStatisticsCollectionQuery>, *mut HKStatisticsCollection, *mut NSError)>>, )

Available on crate feature block2 only.

Setter for initialResultsHandler.

This is copied when set.

Safety
  • initial_results_handler block must be sendable.
  • This might not be thread-safe.
pub unsafe fn statisticsUpdateHandler( &self, ) -> *mut DynBlock<dyn Fn(NonNull<HKStatisticsCollectionQuery>, *mut HKStatistics, *mut HKStatisticsCollection, *mut NSError)>

Available on crate features HKStatistics and block2 only.

This property is not atomic.

Safety
  • The returned block must be sendable.
  • This might not be thread-safe.
pub unsafe fn setStatisticsUpdateHandler( &self, statistics_update_handler: Option<&DynBlock<dyn Fn(NonNull<HKStatisticsCollectionQuery>, *mut HKStatistics, *mut HKStatisticsCollection, *mut NSError)>>, )

Available on crate features HKStatistics and block2 only.

Setter for statisticsUpdateHandler.

This is copied when set.

Safety
  • statistics_update_handler block must be sendable.
  • This might not be thread-safe.
pub unsafe fn initWithQuantityType_quantitySamplePredicate_options_anchorDate_intervalComponents( this: Allocated<Self>, quantity_type: &HKQuantityType, quantity_sample_predicate: Option<&NSPredicate>, options: HKStatisticsOptions, anchor_date: &NSDate, interval_components: &NSDateComponents, ) -> Retained<Self>

Available on crate features HKObjectType and HKStatistics only.
Source

impl HKStatisticsCollectionQuery

Methods declared on superclass HKQuery.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

Source

impl HKStatisticsCollectionQuery

Methods declared on superclass NSObject.

pub unsafe fn new() -> Retained<Self>

Methods from Deref<Target = HKQuery>

pub unsafe fn objectType(&self) -> Option<Retained<HKObjectType>>

Available on crate feature HKObjectType only.
pub unsafe fn sampleType(&self) -> Option<Retained<HKSampleType>>

👎Deprecated
Available on crate feature HKObjectType only.
pub unsafe fn predicate(&self) -> Option<Retained<NSPredicate>>

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}